# Serializers API

::: d3_bridge.data.serializers.serialize_data
    options:
      show_source: false

::: d3_bridge.data.serializers.serialize_queryset
    options:
      show_source: false

::: d3_bridge.data.serializers.serialize_geojson
    options:
      show_source: false
